@@ -26,8 +26,8 @@ __copyright__ = """
 2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 """
 
-__version__ = "0.1.1"
+__version__ = "0.2.0"
 
 repo_root = pathlib.Path(__file__).parent
 install_requires = (repo_root / "requirements.txt").read_text(encoding="utf-8").split('\n')
-extras_require = {"all": []}
+extras_require = {"testing": ["pytest>=6.0.0", "betamax>=0.8.1"], "all": ["betamax>=0.8.1", "pytest>=6.0.0"]}
